@@ -15,19 +15,21 @@ class Encryption(Feature):
             EnableKeyRotation=True,
             KeyPolicy={
                 "Version": "2012-10-17",
-                "Statement": [{
-                    "Sid": "Enable IAM User Permissions",
-                    "Effect": "Allow",
-                    "Principal": {
-                        "AWS": "arn:aws:iam::${aws:accountId}:root"
-                    },
-                    "Action": "kms:*",
-                    "Resource": "*"
-                }]
-            }
+                "Statement": [
+                    {
+                        "Sid": "Enable IAM User Permissions",
+                        "Effect": "Allow",
+                        "Principal": {"AWS": "arn:aws:iam::${aws:accountId}:root"},
+                        "Action": "kms:*",
+                        "Resource": "*",
+                    }
+                ],
+            },
         )
 
-        self.alias = Alias("ServiceEncryptionKeyAlias", AliasName="alias/${self:service}", TargetKeyId=self.key.Ref())
+        self.alias = Alias(
+            "ServiceEncryptionKeyAlias", AliasName="alias/${self:service}-${sls:stage}", TargetKeyId=self.key.Ref()
+        )
 
     def enable(self, service):
         service.resources.add(self.key)
